@@ -41,6 +41,10 @@
 
 #define d(x)
 
+#define E_CONTACT_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), E_TYPE_CONTACT, EContactPrivate))
+
 G_DEFINE_TYPE (EContact, e_contact, E_TYPE_VCARD)
 
 struct _EContactPrivate {
@@ -116,8 +120,10 @@ static const EContactFieldInfo field_info[] = {
 	{0,}, /* Dummy row as EContactField starts from 1 */
 	STRING_FIELD (E_CONTACT_UID,        EVC_UID,       "id",         N_("Unique ID"),  FALSE),
 	/* FILE_AS is not really a structured field - we use a getter/setter
- *         so we can generate its value if necessary in the getter */
-	GETSET_FIELD (E_CONTACT_FILE_AS,    EVC_X_FILE_AS, "file_as",    N_("File Under"),    FALSE, fileas_getter, fileas_setter),
+	 * so we can generate its value if necessary in the getter */
+	/* Translators: This is an EContact field description, in this case it's a
+	   preferred user's description (or display name) of the contact. Note 'File' is a verb here. */
+	GETSET_FIELD (E_CONTACT_FILE_AS,    EVC_X_FILE_AS, "file_as", N_("File Under"),    FALSE, fileas_getter, fileas_setter),
 	/* URI of the book to which the contact belongs to */
 	STRING_FIELD (E_CONTACT_BOOK_URI, EVC_X_BOOK_URI, "book_uri", N_("Book URI"), FALSE),
 
@@ -231,6 +237,9 @@ static const EContactFieldInfo field_info[] = {
 
 	/* Last modified time */
 	STRING_FIELD (E_CONTACT_REV, EVC_REV, "Rev", N_("Last Revision"), FALSE),
+	/* Translators: This is an EContact field description, in this case it's a
+	   virtual field, which returns either name of the contact or the organization
+	   name, recognized by multiple other fields, where the first filled is used. */
 	SYNTH_STR_FIELD     (E_CONTACT_NAME_OR_ORG,               "name_or_org", N_("Name or Org"), TRUE),
 
 	/* Address fields */
@@ -246,7 +255,9 @@ static const EContactFieldInfo field_info[] = {
 	STRUCT_FIELD    (E_CONTACT_PHOTO, EVC_PHOTO, "photo", N_("Photo"), FALSE, photo_getter, photo_setter, e_contact_photo_get_type),
 	STRUCT_FIELD    (E_CONTACT_LOGO,  EVC_LOGO,  "logo",  N_("Logo"),  FALSE, photo_getter, photo_setter, e_contact_photo_get_type),
 
-	STRUCT_FIELD        (E_CONTACT_NAME,        EVC_N,        "name",        N_("Name"),        FALSE, n_getter, n_setter, e_contact_name_get_type),
+	/* Translators: This is an EContact field description, in this case it's a name
+	   of the contact, as specified in http://tools.ietf.org/html/rfc6350#section-6.2.2 */
+	STRUCT_FIELD        (E_CONTACT_NAME,        EVC_N,        "name", N_("Name"),        FALSE, n_getter, n_setter, e_contact_name_get_type),
 	MULTI_LIST_FIELD     (E_CONTACT_EMAIL,      EVC_EMAIL,        "email",      N_("Email List"),      FALSE),
 
 	/* Instant messaging fields */
@@ -259,7 +270,14 @@ static const EContactFieldInfo field_info[] = {
 
 	BOOLEAN_FIELD        (E_CONTACT_WANTS_HTML, EVC_X_WANTS_HTML, "wants_html", N_("Wants HTML Mail"), FALSE),
 
+	/* Translators: This is an EContact field description, in this case it's a
+	   field describing whether it's a Contact list (list of email addresses) or a
+	   regular contact for one person/organization/... */
 	BOOLEAN_FIELD (E_CONTACT_IS_LIST,             EVC_X_LIST, "list", N_("List"), FALSE),
+	/* Translators: This is an EContact field description, in this case it's a flag
+	   used to determine whether when sending to Contact lists the addresses should be
+	   shown or not to other recipients - basically whether to use BCC field or CC
+	   message header when sending messages to this Contact list. */
 	BOOLEAN_FIELD (E_CONTACT_LIST_SHOW_ADDRESSES, EVC_X_LIST_SHOW_ADDRESSES, "list_show_addresses", N_("List Show Addresses"), FALSE),
 
 	STRUCT_FIELD (E_CONTACT_BIRTH_DATE,  EVC_BDAY,          "birth_date",  N_("Birth Date"), FALSE, date_getter, date_setter, e_contact_date_get_type),
@@ -306,42 +324,36 @@ static const EContactFieldInfo field_info[] = {
 #undef LIST_FIELD
 #undef GETSET_FIELD
 
-static GObjectClass *parent_class;
-
 static void e_contact_set_property (GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
 static void e_contact_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec *pspec);
 
 static void
 e_contact_finalize (GObject *object)
 {
-	EContact *ec = E_CONTACT (object);
+	EContactPrivate *priv;
 	gint i;
 
-	for (i = E_CONTACT_FIELD_FIRST; i < E_CONTACT_FIELD_LAST; i++) {
-		g_free (ec->priv->cached_strings[i]);
-	}
+	priv = E_CONTACT_GET_PRIVATE (object);
 
-	if (ec->priv) {
-		g_free (ec->priv);
-		ec->priv = NULL;
-	}
+	for (i = E_CONTACT_FIELD_FIRST; i < E_CONTACT_FIELD_LAST; i++)
+		g_free (priv->cached_strings[i]);
 
-	G_OBJECT_CLASS (parent_class)->finalize (object);
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (e_contact_parent_class)->finalize (object);
 }
 
 static void
-e_contact_class_init (EContactClass *klass)
+e_contact_class_init (EContactClass *class)
 {
 	GObjectClass *object_class;
 	gint i;
 
-	object_class = G_OBJECT_CLASS (klass);
+	g_type_class_add_private (class, sizeof (EContactPrivate));
 
-	parent_class = g_type_class_ref (E_TYPE_VCARD);
-
-	object_class->finalize = e_contact_finalize;
+	object_class = G_OBJECT_CLASS (class);
 	object_class->set_property = e_contact_set_property;
 	object_class->get_property = e_contact_get_property;
+	object_class->finalize = e_contact_finalize;
 
 	for (i = E_CONTACT_FIELD_FIRST; i < E_CONTACT_FIELD_LAST; i++) {
 		GParamSpec *pspec = NULL;
@@ -385,11 +397,9 @@ e_contact_class_init (EContactClass *klass)
 static void
 e_contact_init (EContact *ec)
 {
-	ec->priv = g_new0 (EContactPrivate, 1);
+	ec->priv = E_CONTACT_GET_PRIVATE (ec);
 }
 
-
-
 static gpointer
 geo_getter (EContact *contact,
             EVCardAttribute *attr)
