@@ -169,6 +169,31 @@ typedef enum {
 
 #define E_TYPE_VCARD_PARAM_ATTRIBUTE  (e_vcard_attribute_param_get_type ())
 
+/**
+ * E_VCARD_21_VALID_PROPERTIES:
+ *
+ * FIXME: Document me!
+ *
+ * Since: 3.4
+ **/
+#define E_VCARD_21_VALID_PROPERTIES \
+	"ADR,ORG,N,AGENT,LOGO,PHOTO,LABEL,FN,TITLE,SOUND,VERSION,TEL," \
+	"EMAIL,TZ,GEO,NOTE,URL,BDAY,ROLE,REV,UID,KEY,MAILER"
+
+/**
+ * E_VCARD_21_VALID_PARAMETERS:
+ *
+ * FIXME: Document me!
+ *
+ * Since: 3.4
+ **/
+#define E_VCARD_21_VALID_PARAMETERS \
+	"TYPE,VALUE,ENCODING,CHARSET,LANGUAGE,DOM,INTL,POSTAL,PARCEL," \
+	"HOME,WORK,PREF,VOICE,FAX,MSG,CELL,PAGER,BBS,MODEM,CAR,ISDN,VIDEO," \
+	"AOL,APPLELINK,ATTMAIL,CIS,EWORLD,INTERNET,IBMMAIL,MCIMAIL," \
+	"POWERSHARE,PRODIGY,TLX,X400,GIF,CGM,WMF,BMP,MET,PMB,DIB,PICT,TIFF," \
+	"PDF,PS,JPEG,QTIME,MPEG,MPEG2,AVI,WAVE,AIFF,PCM,X509,PGP"
+
 typedef struct _EVCard EVCard;
 typedef struct _EVCardClass EVCardClass;
 typedef struct _EVCardPrivate EVCardPrivate;
@@ -195,6 +220,7 @@ struct _EVCardClass {
 GType   e_vcard_get_type                     (void);
 
 void    e_vcard_construct                    (EVCard *evc, const gchar *str);
+void    e_vcard_construct_with_uid           (EVCard *evc, const gchar *str, const gchar *uid);
 EVCard * e_vcard_new                          (void);
 EVCard * e_vcard_new_from_string              (const gchar *str);
 
@@ -247,6 +273,7 @@ void                  e_vcard_attribute_param_remove_values   (EVCardAttributePa
 /* EVCard* accessors.  nothing returned from these functions should be
  * freed by the caller. */
 EVCardAttribute *e_vcard_get_attribute        (EVCard *evc, const gchar *name);
+EVCardAttribute *e_vcard_get_attribute_if_parsed	(EVCard *evc, const gchar *name);
 GList *           e_vcard_get_attributes       (EVCard *evcard);
 const gchar *      e_vcard_attribute_get_group  (EVCardAttribute *attr);
 const gchar *      e_vcard_attribute_get_name   (EVCardAttribute *attr);
