@@ -256,6 +256,9 @@ camel_provider_flags_get_type (void)
       { CAMEL_PROVIDER_DISABLE_SENT_FOLDER, "CAMEL_PROVIDER_DISABLE_SENT_FOLDER", "disable-sent-folder" },
       { CAMEL_PROVIDER_ALLOW_REAL_TRASH_FOLDER, "CAMEL_PROVIDER_ALLOW_REAL_TRASH_FOLDER", "allow-real-trash-folder" },
       { CAMEL_PROVIDER_ALLOW_REAL_JUNK_FOLDER, "CAMEL_PROVIDER_ALLOW_REAL_JUNK_FOLDER", "allow-real-junk-folder" },
+      { CAMEL_PROVIDER_SUPPORTS_MOBILE_DEVICES, "CAMEL_PROVIDER_SUPPORTS_MOBILE_DEVICES", "supports-mobile-devices" },
+      { CAMEL_PROVIDER_SUPPORTS_BATCH_FETCH, "CAMEL_PROVIDER_SUPPORTS_BATCH_FETCH", "supports-batch-fetch" },
+      { CAMEL_PROVIDER_SUPPORTS_PURGE_MESSAGE_CACHE, "CAMEL_PROVIDER_SUPPORTS_PURGE_MESSAGE_CACHE", "supports-purge-message-cache" },
       { 0, NULL, NULL }
     };
     etype = g_flags_register_static ("CamelProviderFlags", values);
