@@ -47,17 +47,17 @@ free_fi (CamelPOP3Folder *pop3_folder,CamelPOP3FolderInfo *fi)
 	CamelPOP3Store *pop3_store;
 	CamelStore *store;
 
-	store = camel_folder_get_parent_store ((CamelFolder *)pop3_folder);
-	pop3_store = CAMEL_POP3_STORE(store);
+	store = camel_folder_get_parent_store ((CamelFolder *) pop3_folder);
+	pop3_store = CAMEL_POP3_STORE (store);
 
-	g_hash_table_remove (pop3_folder->uids_id, GINT_TO_POINTER(fi->id));
+	g_hash_table_remove (pop3_folder->uids_id, GINT_TO_POINTER (fi->id));
 	if (fi->cmd) {
 		camel_pop3_engine_command_free (pop3_store->engine, fi->cmd);
 		fi->cmd = NULL;
 	}
 	g_free (fi->uid);
 	g_free (fi);
-	
+
 }
 static void
 cmd_uidl (CamelPOP3Engine *pe,
@@ -154,19 +154,19 @@ cmd_list (CamelPOP3Engine *pe,
 	CamelStore *parent_store;
 	CamelPOP3Store *pop3_store;
 	CamelPOP3FolderInfo *fi;
-	int i=0, total, last_uid=-1;
+	gint i = 0, total, last_uid=-1;
 	CamelPOP3Folder *pop3_folder;
 	CamelService *service;
 	CamelSettings *settings;
-	int batch_fetch_count;
+	gint batch_fetch_count;
 
 	parent_store = camel_folder_get_parent_store (folder);
 	pop3_store = CAMEL_POP3_STORE (parent_store);
-	pop3_folder = (CamelPOP3Folder *)folder;
+	pop3_folder = (CamelPOP3Folder *) folder;
 	service = (CamelService *) parent_store;
 	settings = camel_service_get_settings (service);
 
-	batch_fetch_count = camel_pop3_settings_get_batch_fetch_count (CAMEL_POP3_SETTINGS(settings));
+	batch_fetch_count = camel_pop3_settings_get_batch_fetch_count (CAMEL_POP3_SETTINGS (settings));
 
 	do {
 		ret = camel_pop3_stream_line (stream, &line, &len, cancellable, NULL);
@@ -186,14 +186,14 @@ cmd_list (CamelPOP3Engine *pe,
 
 	/* Trim the list for mobile devices*/
 	if (pop3_folder->mobile_mode && pop3_folder->uids->len) {
-		int y=0;
+		gint y = 0;
 		gboolean save_uid = FALSE;
 		CamelNetworkSettings *network_settings;
-		const gchar *host; 
+		const gchar *host;
 
 		network_settings = CAMEL_NETWORK_SETTINGS (settings);
 		host = camel_network_settings_get_host (network_settings);
-		
+
 		d(printf("*********** Mobile mode *************\n"));
 		d(printf("Total Count: %s: %d\n", host, pop3_folder->uids->len));
 
@@ -214,104 +214,103 @@ cmd_list (CamelPOP3Engine *pe,
 		if (last_uid == -1)
 			save_uid = TRUE;
 
-		for (i=total-1; i >= 0; i--) {
+		for (i = total - 1; i >= 0; i--) {
 			fi = pop3_folder->uids->pdata[i];
 
-			if ((last_uid != -1 && last_uid >= fi->id) || (last_uid == -1 && i == total-batch_fetch_count)) {
+			if ((last_uid != -1 && last_uid >= fi->id) || (last_uid == -1 && i == total - batch_fetch_count)) {
 				if (last_uid != -1 && last_uid < fi->id)
-					i++; /* if the last uid was deleted on the server, then we need the last but 1*/
+					i++; /* if the last uid was deleted on the server, then we need the last but 1 */
 				break;
-			} 
-			
+			}
+
 		}
 		if (i> 0 && pop3_folder->fetch_type == CAMEL_FETCH_OLD_MESSAGES && pop3_folder->fetch_more) {
-			int k=0;
+			gint k = 0;
 			/* Lets pull another window of old messages */
 			save_uid = TRUE;
 			/* Decrement 'i' by another batch count or till we reach the first message */
 			d(printf("Fetch more (%d): from %d", pop3_folder->fetch_more, i));
-			for (k=0; k< pop3_folder->fetch_more && i>= 0; k++, i--);
+			for (k = 0; k< pop3_folder->fetch_more && i>= 0; k++, i--);
 			d(printf(" to %d\n", i));
 
 			/* Don't load messages newer than the latest we already had. We had to just get old messages and not 
 			 * new messages. */
-			for (y=i; y<total; y++) {
+			for (y = i; y < total; y++) {
 				fi = pop3_folder->uids->pdata[y];
 				if (fi->id == pop3_folder->latest_id) {
 					/* Delete everything after this. */
 
-					for (y=k+1; y < total; y++) {
+					for (y = k + 1; y < total; y++) {
 						fi = pop3_folder->uids->pdata[y];
 						free_fi (pop3_folder, fi);
 					}
-					g_ptr_array_remove_range (pop3_folder->uids, k+1, total-k-1);
+					g_ptr_array_remove_range (pop3_folder->uids, k + 1, total - k - 1);
 					break;
 				}
 			}
-				
+
 		} else if (pop3_folder->fetch_more == CAMEL_FETCH_NEW_MESSAGES && pop3_folder->fetch_more) {
 			/* We need to download new messages. */
-			int k=0;
+			gint k = 0;
 
-			for (k=i; k<total; k++) {
+			for (k = i; k < total; k++) {
 				fi = pop3_folder->uids->pdata[k];
 				if (fi->id == pop3_folder->latest_id) {
 					/* We need to just download the specified number of messages. */
-					y= (k+pop3_folder->fetch_more) < total ? (k+pop3_folder->fetch_more) : total-1;
+					y= (k + pop3_folder->fetch_more) < total ? (k + pop3_folder->fetch_more) : total - 1;
 					break;
 				}
 			}
 
 		}
-		
+
 		/* Delete the unnecessary old messages */
 		if (i > 0) {
-			int j=0;
+			gint j = 0;
 			/* i is the start of the last fetch UID, so remove everything else from 0 to i */
-			for (; j<i; j++) {
+			for (; j < i; j++) {
 				fi = pop3_folder->uids->pdata[j];
 				free_fi (pop3_folder, fi);
 			}
 			g_ptr_array_remove_range (pop3_folder->uids, 0, i);
 			d(printf("Removing %d uids that are old\n", i));
-			
-		} 
+
+		}
 
 		/* Delete the unnecessary new message references. */
-		if (y+1 < total) {
-			int k;
+		if (y + 1 < total) {
+			gint k;
 
-			for (k=y+1; k < total; k++) {
+			for (k = y + 1; k < total; k++) {
 				fi = pop3_folder->uids->pdata[k];
 				free_fi (pop3_folder, fi);
 			}
-			g_ptr_array_remove_range (pop3_folder->uids, y+1, total-y-1);
+			g_ptr_array_remove_range (pop3_folder->uids, y + 1, total - y - 1);
 		}
 
 		if (save_uid) {
-			char *contents;
+			gchar *contents;
 			gsize len;
-			const char *root;
-			char *path;
-	
+			const gchar *root;
+			gchar *path;
+
 			/* Save the last fetched UID */
-			fi = pop3_folder->uids->pdata[0];			
+			fi = pop3_folder->uids->pdata[0];
 			g_key_file_set_integer (pop3_folder->key_file, "UIDConfig", "last-saved-uid", fi->id);
 			contents = g_key_file_to_data (pop3_folder->key_file, &len, NULL);
 			root = camel_service_get_user_cache_dir (service);
 			path = g_build_filename (root, "uidconfig", NULL);
 			g_file_set_contents (path, contents, len, NULL);
-			g_key_file_load_from_file (pop3_folder->key_file, path, G_KEY_FILE_NONE, NULL);		
+			g_key_file_load_from_file (pop3_folder->key_file, path, G_KEY_FILE_NONE, NULL);
 			g_free (contents);
 			g_free (path);
 			d(printf("Saving last uid %d\n", fi->id));
-			
+
 		}
 
 	}
 
-}	
-
+}
 
 static void
 cmd_tocache (CamelPOP3Engine *pe,
@@ -510,7 +509,6 @@ pop3_folder_get_message_sync (CamelFolder *folder,
 		"auto-fetch", &auto_fetch,
 		NULL);
 
-
 	fi = g_hash_table_lookup (pop3_folder->uids_fi, uid);
 	if (fi == NULL) {
 		g_set_error (
@@ -667,7 +665,7 @@ pop3_folder_refresh_info_sync (CamelFolder *folder,
 		CamelPOP3FolderInfo *last_fi;
 
 		if (pop3_folder->uids->len) {
-			last_fi = pop3_folder->uids->pdata[pop3_folder->uids->len-1];
+			last_fi = pop3_folder->uids->pdata[pop3_folder->uids->len - 1];
 			if (last_fi)
 				pop3_folder->latest_id = last_fi->id;
 			else
@@ -744,25 +742,25 @@ pop3_folder_refresh_info_sync (CamelFolder *folder,
 }
 
 static gboolean
-pop3_fetch_messages_sync (CamelFolder *folder, 
-			  CamelFetchType type,
-			  int limit,
-			  GCancellable *cancellable, 
-			  GError **error)
+pop3_fetch_messages_sync (CamelFolder *folder,
+                          CamelFetchType type,
+                          gint limit,
+                          GCancellable *cancellable,
+                          GError **error)
 {
 	CamelPOP3FolderInfo *fi;
-	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *)folder;
-	int old_len;
+	CamelPOP3Folder *pop3_folder = (CamelPOP3Folder *) folder;
+	gint old_len;
 	CamelStore *parent_store;
 	CamelService *service;
 	CamelSettings *settings;
-	int batch_fetch_count;
+	gint batch_fetch_count;
 
 	parent_store = camel_folder_get_parent_store (folder);
 	service = (CamelService *) parent_store;
 	settings = camel_service_get_settings (service);
 
-	batch_fetch_count = camel_pop3_settings_get_batch_fetch_count (CAMEL_POP3_SETTINGS(settings));
+	batch_fetch_count = camel_pop3_settings_get_batch_fetch_count (CAMEL_POP3_SETTINGS (settings));
 
 	old_len = pop3_folder->uids->len;
 
@@ -770,7 +768,7 @@ pop3_fetch_messages_sync (CamelFolder *folder,
 	fi = pop3_folder->uids->pdata[0];
 	if (type == CAMEL_FETCH_OLD_MESSAGES && fi->id == pop3_folder->first_id)
 		return FALSE;
-	
+
 	pop3_folder->fetch_type = type;
 	pop3_folder->fetch_more = (limit > 0) ? limit : batch_fetch_count;
 	pop3_folder_refresh_info_sync (folder, cancellable, error);
@@ -897,7 +895,7 @@ camel_pop3_folder_class_init (CamelPOP3FolderClass *class)
 	object_class->dispose = pop3_folder_dispose;
 
 	folder_class = CAMEL_FOLDER_CLASS (class);
-	folder_class->fetch_messages_sync = pop3_fetch_messages_sync;	
+	folder_class->fetch_messages_sync = pop3_fetch_messages_sync;
 	folder_class->get_message_count = pop3_folder_get_message_count;
 	folder_class->get_uids = pop3_folder_get_uids;
 	folder_class->free_uids = camel_folder_free_shallow;
@@ -927,7 +925,7 @@ camel_pop3_folder_new (CamelStore *parent,
 
 	service = CAMEL_SERVICE (parent);
 	settings = camel_service_get_settings (service);
-	
+
 	d(printf("opening pop3 INBOX folder\n"));
 
 	folder = g_object_new (
@@ -941,10 +939,10 @@ camel_pop3_folder_new (CamelStore *parent,
 	pop3_folder->fetch_more = 0;
 	if (pop3_folder->mobile_mode) {
 		/* Setup Keyfile */
-		char *path;
-		const char *root;
+		gchar *path;
+		const gchar *root;
 
-		pop3_folder->key_file = g_key_file_new();
+		pop3_folder->key_file = g_key_file_new ();
 		root = camel_service_get_user_cache_dir (service);
 		path = g_build_filename (root, "uidconfig", NULL);
 		g_key_file_load_from_file (pop3_folder->key_file, path, G_KEY_FILE_NONE, NULL);
