@@ -35,6 +35,10 @@
 #include "e-client-utils.h"
 #include "e-name-selector.h"
 
+#define E_NAME_SELECTOR_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), E_TYPE_NAME_SELECTOR, ENameSelectorPrivate))
+
 typedef struct {
 	gchar *name;
 	ENameSelectorEntry *entry;
@@ -69,7 +73,7 @@ reset_pointer_cb (gpointer data,
 
 	g_return_if_fail (E_IS_NAME_SELECTOR (name_selector));
 
-	priv = name_selector->priv;
+	priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
 
 	for (ii = 0; ii < priv->sections->len; ii++) {
 		Section *section;
@@ -231,7 +235,7 @@ name_selector_dispose (GObject *object)
 	ENameSelectorPrivate *priv;
 	guint ii;
 
-	priv = E_NAME_SELECTOR (object)->priv;
+	priv = E_NAME_SELECTOR_GET_PRIVATE (object);
 
 	if (priv->cancellable) {
 		g_cancellable_cancel (priv->cancellable);
@@ -274,7 +278,7 @@ name_selector_finalize (GObject *object)
 {
 	ENameSelectorPrivate *priv;
 
-	priv = E_NAME_SELECTOR (object)->priv;
+	priv = E_NAME_SELECTOR_GET_PRIVATE (object);
 
 	g_array_free (priv->source_books, TRUE);
 	g_array_free (priv->sections, TRUE);
@@ -304,8 +308,7 @@ e_name_selector_init (ENameSelector *name_selector)
 	sections = g_array_new (FALSE, FALSE, sizeof (Section));
 	source_books = g_array_new (FALSE, FALSE, sizeof (SourceBook));
 
-	name_selector->priv = G_TYPE_INSTANCE_GET_PRIVATE (
-		name_selector, E_TYPE_NAME_SELECTOR, ENameSelectorPrivate);
+	name_selector->priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
 	name_selector->priv->sections = sections;
 	name_selector->priv->model = e_name_selector_model_new ();
 	name_selector->priv->source_books = source_books;
@@ -470,7 +473,7 @@ e_name_selector_peek_section_entry (ENameSelector *name_selector,
 	g_return_val_if_fail (E_IS_NAME_SELECTOR (name_selector), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 
-	priv = name_selector->priv;
+	priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
 	model = e_name_selector_peek_model (name_selector);
 
 	if (!e_name_selector_model_peek_section (
@@ -539,7 +542,7 @@ e_name_selector_peek_section_list (ENameSelector *name_selector,
 	g_return_val_if_fail (E_IS_NAME_SELECTOR (name_selector), NULL);
 	g_return_val_if_fail (name != NULL, NULL);
 
-	priv = name_selector->priv;
+	priv = E_NAME_SELECTOR_GET_PRIVATE (name_selector);
 	model = e_name_selector_peek_model (name_selector);
 
 	if (!e_name_selector_model_peek_section (
