@@ -41,6 +41,7 @@
 #endif
 
 #include <libedata-cal/e-data-cal-factory.h>
+#include <libedataserver/e-gdbus-templates.h>
 
 static gboolean opt_keep_running = FALSE;
 static gboolean opt_wait_for_client = FALSE;
@@ -124,6 +125,8 @@ main (gint argc,
 	/* Migrate user data from ~/.evolution to XDG base directories. */
 	evolution_calendar_factory_migrate_basedir ();
 
+	e_gdbus_templates_init_main_thread ();
+
 	server = e_data_cal_factory_new (NULL, &error);
 
 	if (error != NULL) {
